#include <gio/gio.h>

#if defined (__ELF__) && ( __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 6))
# define SECTION __attribute__ ((section (".gresource.wncklet"), aligned (8)))
#else
# define SECTION
#endif

#ifdef _MSC_VER
static const SECTION union { const guint8 data[3701]; const double alignment; void * const ptr;}  wncklet_resource_data = { {
  0107, 0126, 0141, 0162, 0151, 0141, 0156, 0164, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 
  0030, 0000, 0000, 0000, 0070, 0001, 0000, 0000, 0000, 0000, 0000, 0050, 0012, 0000, 0000, 0000, 
  0000, 0000, 0000, 0000, 0001, 0000, 0000, 0000, 0002, 0000, 0000, 0000, 0005, 0000, 0000, 0000, 
  0006, 0000, 0000, 0000, 0006, 0000, 0000, 0000, 0007, 0000, 0000, 0000, 0011, 0000, 0000, 0000, 
  0011, 0000, 0000, 0000, 0012, 0000, 0000, 0000, 0324, 0265, 0002, 0000, 0377, 0377, 0377, 0377, 
  0070, 0001, 0000, 0000, 0001, 0000, 0114, 0000, 0074, 0001, 0000, 0000, 0100, 0001, 0000, 0000, 
  0157, 0330, 0366, 0224, 0011, 0000, 0000, 0000, 0100, 0001, 0000, 0000, 0006, 0000, 0114, 0000, 
  0110, 0001, 0000, 0000, 0114, 0001, 0000, 0000, 0276, 0100, 0116, 0365, 0005, 0000, 0000, 0000, 
  0114, 0001, 0000, 0000, 0032, 0000, 0166, 0000, 0150, 0001, 0000, 0000, 0015, 0002, 0000, 0000, 
  0230, 0045, 0111, 0067, 0005, 0000, 0000, 0000, 0015, 0002, 0000, 0000, 0016, 0000, 0166, 0000, 
  0040, 0002, 0000, 0000, 0362, 0006, 0000, 0000, 0032, 0212, 0367, 0210, 0005, 0000, 0000, 0000, 
  0362, 0006, 0000, 0000, 0023, 0000, 0166, 0000, 0010, 0007, 0000, 0000, 0250, 0007, 0000, 0000, 
  0253, 0234, 0262, 0161, 0010, 0000, 0000, 0000, 0250, 0007, 0000, 0000, 0010, 0000, 0114, 0000, 
  0260, 0007, 0000, 0000, 0300, 0007, 0000, 0000, 0113, 0120, 0220, 0013, 0000, 0000, 0000, 0000, 
  0300, 0007, 0000, 0000, 0004, 0000, 0114, 0000, 0304, 0007, 0000, 0000, 0310, 0007, 0000, 0000, 
  0274, 0045, 0206, 0141, 0005, 0000, 0000, 0000, 0310, 0007, 0000, 0000, 0025, 0000, 0166, 0000, 
  0340, 0007, 0000, 0000, 0134, 0016, 0000, 0000, 0104, 0237, 0231, 0330, 0001, 0000, 0000, 0000, 
  0134, 0016, 0000, 0000, 0007, 0000, 0114, 0000, 0144, 0016, 0000, 0000, 0150, 0016, 0000, 0000, 
  0260, 0267, 0044, 0060, 0006, 0000, 0000, 0000, 0150, 0016, 0000, 0000, 0006, 0000, 0114, 0000, 
  0160, 0016, 0000, 0000, 0164, 0016, 0000, 0000, 0057, 0000, 0000, 0000, 0006, 0000, 0000, 0000, 
  0160, 0141, 0156, 0145, 0154, 0057, 0000, 0000, 0010, 0000, 0000, 0000, 0167, 0157, 0162, 0153, 
  0163, 0160, 0141, 0143, 0145, 0055, 0163, 0167, 0151, 0164, 0143, 0150, 0145, 0162, 0055, 0155, 
  0145, 0156, 0165, 0056, 0165, 0151, 0000, 0000, 0031, 0001, 0000, 0000, 0001, 0000, 0000, 0000, 
  0170, 0332, 0175, 0120, 0101, 0016, 0302, 0060, 0014, 0273, 0357, 0025, 0125, 0357, 0243, 0037, 
  0350, 0372, 0006, 0176, 0200, 0322, 0342, 0211, 0212, 0266, 0233, 0322, 0114, 0023, 0277, 0247, 
  0003, 0301, 0220, 0220, 0166, 0264, 0343, 0070, 0166, 0154, 0054, 0002, 0036, 0051, 0300, 0165, 
  0112, 0331, 0214, 0262, 0250, 0170, 0035, 0364, 0072, 0361, 0275, 0316, 0215, 0356, 0353, 0032, 
  0045, 0334, 0300, 0375, 0066, 0323, 0233, 0252, 0351, 0052, 0202, 0304, 0251, 0274, 0121, 0303, 
  0121, 0220, 0077, 0240, 0101, 0022, 0341, 0350, 0027, 0201, 0052, 0224, 0061, 0350, 0104, 0036, 
  0111, 0053, 0141, 0052, 0065, 0221, 0220, 0117, 0215, 0174, 0240, 0152, 0167, 0071, 0063, 0106, 
  0060, 0112, 0100, 0265, 0346, 0273, 0167, 0340, 0105, 0257, 0313, 0332, 0375, 0047, 0074, 0315, 
  0207, 0136, 0326, 0354, 0051, 0255, 0371, 0151, 0140, 0315, 0126, 0315, 0165, 0115, 0260, 0077, 
  0343, 0011, 0160, 0207, 0133, 0067, 0000, 0050, 0165, 0165, 0141, 0171, 0051, 0167, 0151, 0156, 
  0144, 0157, 0167, 0055, 0154, 0151, 0163, 0164, 0056, 0165, 0151, 0000, 0000, 0000, 0000, 0000, 
  0244, 0076, 0000, 0000, 0001, 0000, 0000, 0000, 0170, 0332, 0355, 0133, 0335, 0163, 0342, 0066, 
  0020, 0177, 0277, 0277, 0102, 0325, 0153, 0207, 0020, 0223, 0266, 0227, 0316, 0200, 0157, 0222, 
  0273, 0134, 0172, 0163, 0371, 0232, 0204, 0233, 0173, 0324, 0010, 0173, 0001, 0065, 0102, 0242, 
  0222, 0214, 0223, 0116, 0377, 0370, 0312, 0066, 0011, 0044, 0010, 0214, 0015, 0327, 0320, 0104, 
  0157, 0301, 0332, 0135, 0153, 0177, 0253, 0375, 0214, 0325, 0376, 0160, 0067, 0342, 0150, 0002, 
  0112, 0063, 0051, 0072, 0070, 0330, 0333, 0307, 0010, 0104, 0044, 0143, 0046, 0006, 0035, 0374, 
  0255, 0373, 0271, 0161, 0210, 0077, 0204, 0357, 0332, 0077, 0065, 0032, 0350, 0024, 0004, 0050, 
  0152, 0040, 0106, 0051, 0063, 0103, 0064, 0340, 0064, 0006, 0164, 0260, 0027, 0034, 0356, 0035, 
  0240, 0106, 0303, 0022, 0061, 0141, 0100, 0365, 0151, 0004, 0341, 0073, 0204, 0332, 0012, 0376, 
  0112, 0230, 0002, 0215, 0070, 0353, 0165, 0360, 0300, 0334, 0376, 0214, 0147, 0057, 0262, 0154, 
  0055, 0334, 0314, 0351, 0144, 0357, 0117, 0210, 0014, 0212, 0070, 0325, 0272, 0203, 0117, 0315, 
  0355, 0047, 0106, 0271, 0034, 0140, 0304, 0342, 0016, 0066, 0124, 0337, 0162, 0246, 0015, 0031, 
  0053, 0071, 0006, 0145, 0030, 0150, 0022, 0027, 0353, 0031, 0263, 0145, 0237, 0056, 0334, 0043, 
  0101, 0107, 0320, 0301, 0021, 0025, 0244, 0057, 0243, 0104, 0343, 0360, 0063, 0345, 0032, 0332, 
  0315, 0007, 0002, 0067, 0175, 0117, 0252, 0030, 0024, 0111, 0131, 0154, 0206, 0070, 0374, 0265, 
  0214, 0334, 0060, 0303, 0001, 0043, 0243, 0250, 0320, 0234, 0032, 0332, 0343, 0366, 0341, 0075, 
  0330, 0267, 0175, 0147, 0042, 0226, 0051, 0072, 0263, 0233, 0105, 0127, 0012, 0372, 0240, 0054, 
  0216, 0240, 0113, 0005, 0336, 0217, 0201, 0014, 0055, 0162, 0070, 0024, 0122, 0215, 0050, 0137, 
  0140, 0210, 0206, 0214, 0307, 0050, 0307, 0126, 0120, 0336, 0310, 0177, 0166, 0360, 0244, 0047, 
  0357, 0246, 0020, 0270, 0060, 0074, 0266, 0253, 0071, 0200, 0005, 0130, 0215, 0214, 0274, 0365, 
  0110, 0277, 0270, 0215, 0011, 0323, 0314, 0352, 0202, 0303, 0256, 0112, 0026, 0060, 0253, 0203, 
  0263, 0213, 0107, 0052, 0006, 0302, 0120, 0143, 0117, 0000, 0016, 0047, 0231, 0065, 0243, 0105, 
  0175, 0135, 0214, 0172, 0114, 0043, 0173, 0040, 0161, 0330, 0162, 0122, 0347, 0220, 0314, 0176, 
  0257, 0304, 0043, 0003, 0042, 0300, 0363, 0304, 0065, 0300, 0250, 0013, 0310, 0106, 0240, 0270, 
  0230, 0141, 0142, 0171, 0355, 0033, 0117, 0077, 0175, 0045, 0127, 0227, 0137, 0056, 0272, 0047, 
  0327, 0344, 0374, 0262, 0373, 0345, 0362, 0202, 0234, 0037, 0335, 0174, 0105, 0377, 0040, 0307, 
  0312, 0037, 0366, 0327, 0374, 0362, 0361, 0267, 0156, 0327, 0076, 0276, 0272, 0076, 0271, 0271, 
  0161, 0074, 0277, 0076, 0071, 0073, 0071, 0272, 0071, 0311, 0127, 0326, 0335, 0127, 0211, 0127, 
  0225, 0332, 0071, 0070, 0134, 0312, 0262, 0140, 0354, 0065, 0014, 0376, 0036, 0077, 0147, 0250, 
  0151, 0364, 0115, 0014, 0277, 0261, 0361, 0127, 0042, 0366, 0333, 0112, 0056, 0047, 0150, 0156, 
  0340, 0316, 0150, 0017, 0170, 0001, 0035, 0317, 0376, 0014, 0260, 0213, 0157, 0003, 0374, 0066, 
  0305, 0320, 0305, 0177, 0107, 0071, 0033, 0130, 0010, 0367, 0253, 0062, 0362, 0102, 0333, 0222, 
  0170, 0376, 0121, 0332, 0350, 0053, 0114, 0251, 0160, 0152, 0214, 0142, 0275, 0304, 0200, 0166, 
  0023, 0314, 0223, 0114, 0067, 0220, 0002, 0033, 0014, 0215, 0315, 0214, 0224, 0047, 0271, 0343, 
  0360, 0270, 0310, 0213, 0016, 0336, 0346, 0152, 0371, 0355, 0146, 0141, 0114, 0347, 0232, 0075, 
  0047, 0267, 0366, 0240, 0254, 0207, 0012, 0334, 0215, 0251, 0210, 0153, 0332, 0242, 0317, 0070, 
  0257, 0311, 0072, 0226, 0232, 0025, 0276, 0120, 0142, 0110, 0273, 0272, 0114, 0237, 0166, 0163, 
  0311, 0141, 0257, 0342, 0004, 0117, 0242, 0307, 0357, 0377, 0007, 0017, 0030, 0121, 0065, 0140, 
  0202, 0150, 0103, 0225, 0055, 0045, 0202, 0126, 0125, 0376, 0312, 0221, 0250, 0176, 0064, 0132, 
  0155, 0014, 0267, 0101, 0256, 0151, 0314, 0344, 0161, 0142, 0214, 0335, 0136, 0156, 0030, 0075, 
  0224, 0051, 0211, 0022, 0145, 0253, 0054, 0103, 0124, 0266, 0212, 0227, 0111, 0253, 0342, 0365, 
  0067, 0103, 0142, 0235, 0076, 0315, 0175, 0137, 0243, 0276, 0222, 0043, 0064, 0175, 0011, 0112, 
  0245, 0272, 0315, 0024, 0054, 0065, 0315, 0306, 0147, 0243, 0344, 0174, 0324, 0025, 0241, 0040, 
  0002, 0066, 0311, 0012, 0150, 0350, 0323, 0204, 0233, 0065, 0117, 0232, 0113, 0124, 0242, 0201, 
  0044, 0302, 0246, 0170, 0316, 0304, 0006, 0112, 0255, 0035, 0266, 0135, 0314, 0064, 0062, 0126, 
  0233, 0372, 0057, 0217, 0025, 0115, 0211, 0065, 0264, 0075, 0350, 0106, 0252, 0165, 0345, 0254, 
  0012, 0262, 0345, 0201, 0166, 0343, 0140, 0273, 0141, 0300, 0335, 0050, 0350, 0226, 0004, 0336, 
  0225, 0301, 0167, 0173, 0076, 0117, 0071, 0337, 0252, 0277, 0077, 0167, 0167, 0112, 0070, 0237, 
  0371, 0272, 0366, 0316, 0276, 0023, 0316, 0136, 0317, 0131, 0027, 0345, 0014, 0224, 0114, 0306, 
  0070, 0134, 0314, 0036, 0157, 0333, 0363, 0203, 0037, 0351, 0371, 0073, 0125, 0227, 0326, 0251, 
  0315, 0326, 0306, 0251, 0172, 0131, 0272, 0014, 0233, 0345, 0270, 0324, 0306, 0244, 0036, 0036, 
  0265, 0262, 0305, 0022, 0034, 0234, 0030, 0324, 0152, 0350, 0203, 0300, 0167, 0364, 0265, 0073, 
  0372, 0203, 0267, 0335, 0321, 0237, 0146, 0051, 0300, 0042, 0354, 0273, 0371, 0067, 0331, 0315, 
  0007, 0055, 0337, 0316, 0357, 0136, 0073, 0057, 0300, 0156, 0222, 0344, 0325, 0331, 0026, 0253, 
  0173, 0162, 0221, 0211, 0105, 0271, 0330, 0207, 0052, 0337, 0027, 0364, 0276, 0173, 0367, 0335, 
  0373, 0013, 0164, 0357, 0064, 0061, 0162, 0353, 0036, 0176, 0072, 0357, 0332, 0050, 0035, 0202, 
  0100, 0044, 0157, 0334, 0021, 0313, 0376, 0361, 0074, 0142, 0006, 0142, 0357, 0361, 0257, 0261, 
  0205, 0137, 0310, 0030, 0276, 0203, 0337, 0151, 0357, 0347, 0051, 0275, 0327, 0333, 0317, 0360, 
  0107, 0271, 0134, 0237, 0342, 0275, 0303, 0277, 0061, 0207, 0157, 0371, 0221, 0235, 0037, 0331, 
  0125, 0034, 0331, 0005, 0057, 0071, 0262, 0073, 0360, 0043, 0273, 0072, 0043, 0273, 0021, 0023, 
  0266, 0214, 0375, 0033, 0142, 0062, 0315, 0156, 0244, 0310, 0206, 0157, 0163, 0206, 0167, 0015, 
  0332, 0346, 0022, 0013, 0066, 0072, 0177, 0300, 0005, 0175, 0137, 0057, 0353, 0373, 0171, 0336, 
  0353, 0234, 0347, 0375, 0342, 0347, 0171, 0273, 0067, 0317, 0033, 0311, 0011, 0220, 0131, 0350, 
  0332, 0136, 0301, 0137, 0004, 0000, 0100, 0106, 0076, 0176, 0230, 0103, 0374, 0227, 0071, 0176, 
  0266, 0347, 0147, 0173, 0057, 0331, 0335, 0107, 0103, 0052, 0006, 0060, 0163, 0304, 0037, 0343, 
  0360, 0202, 0222, 0354, 0140, 0371, 0057, 0361, 0136, 0167, 0243, 0357, 0312, 0035, 0176, 0270, 
  0347, 0173, 0175, 0337, 0353, 0127, 0351, 0365, 0133, 0333, 0350, 0365, 0135, 0372, 0273, 0165, 
  0257, 0245, 0167, 0165, 0235, 0053, 0333, 0336, 0241, 0353, 0202, 0236, 0113, 0256, 0330, 0145, 
  0145, 0214, 0024, 0204, 0052, 0240, 0270, 0344, 0166, 0131, 0236, 0012, 0237, 0337, 0271, 0233, 
  0343, 0157, 0275, 0350, 0215, 0263, 0165, 0307, 0065, 0163, 0011, 0075, 0226, 0002, 0110, 0257, 
  0170, 0120, 0176, 0352, 0126, 0314, 0347, 0077, 0162, 0131, 0355, 0334, 0157, 0143, 0004, 0124, 
  0207, 0365, 0061, 0025, 0127, 0145, 0036, 0122, 0135, 0237, 0271, 0106, 0045, 0260, 0121, 0005, 
  0360, 0342, 0001, 0255, 0062, 0333, 0226, 0247, 0227, 0273, 0037, 0321, 0354, 0136, 0110, 0166, 
  0053, 0030, 0207, 0040, 0342, 0377, 0060, 0016, 0076, 0105, 0346, 0311, 0142, 0273, 0010, 0145, 
  0215, 0224, 0305, 0003, 0060, 0217, 0343, 0255, 0247, 0217, 0221, 0002, 0075, 0226, 0102, 0333, 
  0335, 0354, 0343, 0160, 0056, 0200, 0264, 0233, 0117, 0350, 0036, 0344, 0057, 0312, 0234, 0355, 
  0240, 0335, 0234, 0273, 0113, 0376, 0057, 0312, 0142, 0114, 0041, 0000, 0050, 0165, 0165, 0141, 
  0171, 0051, 0167, 0151, 0156, 0144, 0157, 0167, 0055, 0154, 0151, 0163, 0164, 0055, 0155, 0145, 
  0156, 0165, 0056, 0165, 0151, 0000, 0000, 0000, 0013, 0001, 0000, 0000, 0001, 0000, 0000, 0000, 
  0170, 0332, 0175, 0217, 0101, 0016, 0203, 0060, 0014, 0004, 0357, 0274, 0042, 0312, 0235, 0346, 
  0003, 0041, 0157, 0350, 0017, 0052, 0003, 0213, 0144, 0051, 0061, 0125, 0142, 0204, 0372, 0373, 
  0046, 0255, 0132, 0070, 0161, 0234, 0365, 0172, 0275, 0366, 0054, 0212, 0274, 0320, 0204, 0320, 
  0031, 0343, 0023, 0144, 0063, 0074, 0017, 0166, 0147, 0231, 0327, 0275, 0217, 0134, 0264, 0157, 
  0242, 0155, 0343, 0152, 0050, 0230, 0224, 0127, 0371, 0122, 0145, 0126, 0244, 0037, 0124, 0044, 
  0325, 0314, 0343, 0246, 0060, 0102, 0011, 0203, 0215, 0064, 0042, 0132, 0243, 0231, 0244, 0104, 
  0122, 0032, 0143, 0025, 0137, 0050, 0066, 0074, 0356, 0031, 0013, 0062, 0144, 0102, 0361, 0356, 
  0277, 0167, 0221, 0105, 0237, 0313, 0066, 0234, 0252, 0335, 0236, 0227, 0041, 0336, 0035, 0365, 
  0274, 0073, 0125, 0367, 0256, 0375, 0024, 0272, 0152, 0070, 0336, 0177, 0003, 0277, 0367, 0125, 
  0157, 0000, 0050, 0165, 0165, 0141, 0171, 0051, 0167, 0156, 0143, 0153, 0154, 0145, 0164, 0057, 
  0004, 0000, 0000, 0000, 0003, 0000, 0000, 0000, 0002, 0000, 0000, 0000, 0007, 0000, 0000, 0000, 
  0157, 0162, 0147, 0057, 0011, 0000, 0000, 0000, 0167, 0157, 0162, 0153, 0163, 0160, 0141, 0143, 
  0145, 0055, 0163, 0167, 0151, 0164, 0143, 0150, 0145, 0162, 0056, 0165, 0151, 0000, 0000, 0000, 
  0256, 0106, 0000, 0000, 0001, 0000, 0000, 0000, 0170, 0332, 0355, 0134, 0337, 0163, 0333, 0050, 
  0020, 0176, 0357, 0137, 0301, 0351, 0365, 0306, 0115, 0234, 0134, 0073, 0275, 0216, 0343, 0116, 
  0177, 0244, 0275, 0116, 0333, 0264, 0023, 0247, 0327, 0107, 0015, 0226, 0326, 0026, 0015, 0006, 
  0035, 0102, 0166, 0162, 0163, 0177, 0374, 0201, 0344, 0330, 0162, 0214, 0054, 0044, 0224, 0306, 
  0116, 0374, 0226, 0010, 0166, 0201, 0135, 0366, 0343, 0323, 0056, 0162, 0357, 0325, 0325, 0204, 
  0242, 0051, 0210, 0204, 0160, 0166, 0342, 0165, 0237, 0036, 0172, 0010, 0130, 0300, 0103, 0302, 
  0306, 0047, 0336, 0367, 0213, 0367, 0235, 0027, 0336, 0253, 0376, 0223, 0336, 0157, 0235, 0016, 
  0372, 0000, 0014, 0004, 0226, 0020, 0242, 0031, 0221, 0021, 0032, 0123, 0034, 0002, 0072, 0176, 
  0332, 0175, 0361, 0364, 0030, 0165, 0072, 0252, 0023, 0141, 0022, 0304, 0010, 0007, 0320, 0177, 
  0202, 0120, 0117, 0300, 0077, 0051, 0021, 0220, 0040, 0112, 0206, 0047, 0336, 0130, 0136, 0376, 
  0356, 0055, 0007, 0122, 0142, 0107, 0336, 0101, 0326, 0217, 0017, 0177, 0102, 0040, 0121, 0100, 
  0161, 0222, 0234, 0170, 0037, 0344, 0345, 0353, 0360, 0147, 0232, 0310, 0011, 0060, 0351, 0041, 
  0022, 0236, 0170, 0054, 0235, 0370, 0202, 0317, 0022, 0037, 0057, 0033, 0264, 0244, 0222, 0215, 
  0005, 0217, 0101, 0310, 0153, 0304, 0360, 0004, 0116, 0074, 0312, 0147, 0040, 0274, 0176, 0267, 
  0167, 0160, 0323, 0140, 0356, 0227, 0306, 0161, 0326, 0357, 0171, 0125, 0307, 0051, 0246, 0051, 
  0130, 0050, 0114, 0044, 0304, 0076, 0141, 0201, 0200, 0174, 0166, 0225, 0002, 0061, 0036, 0303, 
  0212, 0300, 0341, 0252, 0104, 0357, 0040, 0067, 0213, 0275, 0205, 0146, 0134, 0134, 0046, 0261, 
  0062, 0176, 0373, 0166, 0072, 0336, 0125, 0073, 0275, 0043, 0230, 0362, 0161, 0156, 0043, 0255, 
  0111, 0370, 0163, 0131, 0242, 0254, 0024, 0346, 0215, 0346, 0161, 0003, 0314, 0374, 0021, 0017, 
  0322, 0304, 0353, 0277, 0307, 0064, 0201, 0252, 0171, 0016, 0271, 0010, 0225, 0372, 0031, 0011, 
  0145, 0344, 0365, 0237, 0125, 0165, 0227, 0104, 0122, 0360, 0220, 0024, 0230, 0045, 0024, 0113, 
  0074, 0244, 0352, 0341, 0065, 0250, 0321, 0176, 0334, 0270, 0021, 0015, 0124, 0224, 0005, 0021, 
  0010, 0364, 0115, 0300, 0010, 0204, 0212, 0112, 0110, 0252, 0364, 0252, 0160, 0043, 0377, 0152, 
  0155, 0226, 0323, 0226, 0327, 0061, 0370, 0021, 0321, 0226, 0145, 0134, 0114, 0060, 0135, 0023, 
  0010, 0042, 0102, 0103, 0224, 0105, 0066, 0303, 0264, 0223, 0375, 0253, 0374, 0075, 0344, 0127, 
  0163, 0313, 0231, 0354, 0376, 0106, 0265, 0146, 0106, 0317, 0155, 0334, 0321, 0335, 0273, 0213, 
  0376, 0206, 0355, 0103, 0022, 0222, 0115, 0372, 0102, 0244, 0153, 0163, 0156, 0342, 0036, 0223, 
  0014, 0027, 0104, 0155, 0041, 0054, 0025, 0376, 0170, 0375, 0251, 0336, 0004, 0301, 0372, 0172, 
  0215, 0233, 0126, 0271, 0103, 0301, 0241, 0327, 0077, 0062, 0366, 0066, 0133, 0010, 0007, 0172, 
  0040, 0037, 0013, 0300, 0205, 0205, 0033, 0215, 0225, 0112, 0311, 0331, 0155, 0223, 0025, 0344, 
  0273, 0053, 0012, 0032, 0130, 0257, 0251, 0005, 0227, 0313, 0133, 0175, 0126, 0276, 0212, 0371, 
  0022, 0070, 0003, 0177, 0230, 0077, 0270, 0055, 0151, 0000, 0043, 0074, 0004, 0152, 0214, 0005, 
  0377, 0055, 0345, 0345, 0063, 0153, 0154, 0212, 0012, 0163, 0064, 0021, 0015, 0141, 0204, 0123, 
  0052, 0353, 0013, 0107, 0070, 0151, 0056, 0054, 0040, 0000, 0062, 0205, 0202, 0206, 0215, 0256, 
  0064, 0042, 0174, 0002, 0176, 0312, 0024, 0164, 0121, 0302, 0052, 0315, 0126, 0004, 0333, 0125, 
  0245, 0070, 0270, 0124, 0021, 0122, 0075, 0034, 0134, 0305, 0230, 0205, 0015, 0346, 0071, 0042, 
  0224, 0066, 0020, 0213, 0171, 0102, 0362, 0200, 0357, 0156, 0132, 0226, 0161, 0376, 0275, 0203, 
  0265, 0255, 0157, 0062, 0200, 0171, 0361, 0215, 0026, 0156, 0136, 0164, 0235, 0250, 0326, 0163, 
  0361, 0065, 0250, 0173, 0175, 0140, 0241, 0265, 0324, 0302, 0112, 0207, 0146, 0021, 0203, 0205, 
  0326, 0254, 0263, 0016, 0024, 0033, 0316, 0005, 0175, 0040, 0034, 0335, 0053, 0254, 0325, 0073, 
  0277, 0235, 0317, 0224, 0215, 0347, 0112, 0367, 0310, 0025, 0175, 0337, 0013, 0245, 0061, 0067, 
  0355, 0110, 0377, 0331, 0365, 0176, 0015, 0126, 0326, 0016, 0110, 0230, 0052, 0173, 0051, 0301, 
  0017, 0357, 0076, 0371, 0337, 0276, 0176, 0074, 0273, 0070, 0075, 0367, 0277, 0174, 0275, 0370, 
  0370, 0365, 0314, 0377, 0362, 0172, 0360, 0011, 0375, 0207, 0014, 0055, 0177, 0251, 0377, 0212, 
  0315, 0157, 0276, 0137, 0134, 0250, 0307, 0337, 0316, 0117, 0007, 0003, 0303, 0363, 0363, 0323, 
  0317, 0247, 0257, 0007, 0247, 0131, 0113, 0235, 0271, 0145, 0007, 0221, 0177, 0205, 0051, 0031, 
  0227, 0207, 0102, 0211, 0053, 0043, 0034, 0362, 0331, 0074, 0362, 0230, 0072, 0376, 0066, 0012, 
  0033, 0235, 0152, 0021, 0061, 0317, 0074, 0223, 0220, 0203, 0147, 0135, 0275, 0153, 0222, 0237, 
  0140, 0061, 0046, 0314, 0117, 0044, 0026, 0162, 0323, 0326, 0156, 0045, 0244, 0052, 0103, 0353, 
  0171, 0245, 0144, 0251, 0063, 0314, 0016, 0071, 0307, 0041, 0341, 0105, 0262, 0023, 0244, 0102, 
  0161, 0163, 0351, 0163, 0106, 0257, 0175, 0241, 0133, 0275, 0062, 0155, 0165, 0270, 0317, 0040, 
  0342, 0063, 0224, 0051, 0105, 0062, 0002, 0064, 0037, 0005, 0055, 0336, 0362, 0252, 0326, 0345, 
  0274, 0057, 0034, 0131, 0122, 0213, 0234, 0245, 0025, 0356, 0122, 0256, 0306, 0052, 0340, 0313, 
  0204, 0065, 0115, 0237, 0072, 0014, 0036, 0012, 0074, 0123, 0357, 0267, 0241, 0332, 0344, 0222, 
  0013, 0133, 0075, 0145, 0104, 0254, 0232, 0220, 0071, 0023, 0063, 0107, 0202, 0326, 0230, 0202, 
  0130, 0020, 0266, 0015, 0304, 0255, 0171, 0274, 0057, 0000, 0070, 0122, 0000, 0374, 0247, 0167, 
  0077, 0301, 0326, 0330, 0254, 0026, 0024, 0303, 0336, 0070, 0226, 0200, 0210, 0051, 0055, 0046, 
  0243, 0252, 0040, 0261, 0011, 0054, 0252, 0041, 0226, 0110, 0230, 0250, 0167, 0357, 0227, 0066, 
  0253, 0153, 0305, 0113, 0055, 0301, 0142, 0313, 0320, 0330, 0042, 0074, 0072, 0103, 0144, 0173, 
  0060, 0147, 0326, 0065, 0026, 0074, 0215, 0275, 0376, 0372, 0271, 0153, 0247, 0260, 0012, 0073, 
  0355, 0360, 0263, 0025, 0014, 0155, 0001, 0107, 0235, 0261, 0324, 0002, 0117, 0053, 0061, 0265, 
  0051, 0164, 0254, 0140, 0153, 0367, 0320, 0273, 0337, 0320, 0165, 0262, 0271, 0075, 0341, 0264, 
  0067, 0230, 0331, 0150, 0203, 0230, 0260, 0042, 0334, 0056, 0252, 0043, 0211, 0152, 0360, 0252, 
  0364, 0265, 0144, 0306, 0026, 0121, 0320, 0230, 0226, 0206, 0053, 0151, 0204, 0377, 0256, 0213, 
  0326, 0142, 0131, 0304, 0120, 0123, 0162, 0132, 0073, 0045, 0223, 0241, 0257, 0213, 0143, 0216, 
  0163, 0124, 0363, 0002, 0101, 0002, 0167, 0023, 0226, 0125, 0144, 0334, 0200, 0321, 0036, 0034, 
  0133, 0003, 0310, 0146, 0211, 0261, 0073, 0301, 0111, 0113, 0254, 0264, 0302, 0113, 0027, 0010, 
  0370, 0234, 0323, 0043, 0035, 0375, 0171, 0316, 0102, 0355, 0144, 0077, 0340, 0164, 0113, 0242, 
  0337, 0331, 0275, 0265, 0351, 0106, 0075, 0016, 0251, 0343, 0336, 0105, 0263, 0006, 0014, 0062, 
  0272, 0126, 0024, 0004, 0164, 0321, 0307, 0105, 0325, 0204, 0301, 0204, 0063, 0022, 0350, 0304, 
  0343, 0030, 0212, 0270, 0244, 0321, 0374, 0001, 0307, 0256, 0263, 0032, 0253, 0314, 0376, 0335, 
  0005, 0357, 0116, 0260, 0110, 0027, 0142, 0124, 0333, 0276, 0356, 0044, 0162, 0153, 0263, 0032, 
  0115, 0337, 0340, 0153, 0331, 0260, 0171, 0122, 0243, 0334, 0156, 0245, 0102, 0363, 0242, 0265, 
  0316, 0127, 0337, 0040, 0245, 0135, 0076, 0372, 0366, 0321, 0163, 0264, 0013, 0051, 0351, 0155, 
  0052, 0072, 0324, 0114, 0167, 0314, 0357, 0200, 0124, 0152, 0304, 0122, 0012, 0062, 0114, 0045, 
  0044, 0245, 0373, 0153, 0321, 0145, 0076, 0352, 0014, 0310, 0070, 0122, 0064, 0073, 0143, 0212, 
  0272, 0002, 0106, 0303, 0374, 0106, 0226, 0151, 0207, 0155, 0326, 0137, 0173, 0007, 0336, 0173, 
  0045, 0271, 0156, 0315, 0313, 0212, 0053, 0332, 0027, 0222, 0033, 0125, 0366, 0012, 0111, 0265, 
  0254, 0310, 0267, 0257, 0361, 0075, 0300, 0032, 0137, 0167, 0137, 0343, 0273, 0367, 0032, 0337, 
  0112, 0136, 0352, 0217, 0175, 0316, 0177, 0023, 0013, 0270, 0165, 0365, 0264, 0234, 0113, 0354, 
  0110, 0042, 0317, 0071, 0325, 0135, 0176, 0230, 0237, 0245, 0223, 0041, 0010, 0304, 0107, 0250, 
  0140, 0261, 0227, 0133, 0220, 0336, 0157, 0370, 0102, 0153, 0365, 0062, 0133, 0330, 0033, 0366, 
  0257, 0264, 0373, 0034, 0375, 0326, 0344, 0350, 0115, 0351, 0346, 0133, 0076, 0365, 0166, 0267, 
  0344, 0346, 0236, 0150, 0256, 0112, 0062, 0033, 0257, 0345, 0067, 0136, 0165, 0223, 0064, 0163, 
  0053, 0051, 0146, 0267, 0364, 0362, 0076, 0133, 0362, 0210, 0262, 0045, 0017, 0357, 0016, 0110, 
  0201, 0356, 0054, 0302, 0331, 0327, 0163, 0256, 0346, 0073, 0133, 0311, 0020, 0235, 0156, 0074, 
  0225, 0363, 0233, 0345, 0247, 0053, 0014, 0373, 0023, 0113, 0152, 0163, 0107, 0227, 0272, 0326, 
  0270, 0110, 0001, 0207, 0245, 0000, 0360, 0247, 0004, 0146, 0217, 0373, 0242, 0125, 0167, 0273, 
  0202, 0154, 0020, 0010, 0116, 0051, 0204, 0077, 0010, 0123, 0257, 0331, 0346, 0150, 0113, 0262, 
  0076, 0065, 0302, 0055, 0312, 0162, 0134, 0276, 0376, 0024, 0021, 0222, 0354, 0363, 0261, 0303, 
  0135, 0275, 0070, 0271, 0222, 0176, 0260, 0043, 0322, 0115, 0370, 0336, 0205, 0012, 0216, 0277, 
  0125, 0154, 0254, 0245, 0234, 0026, 0121, 0263, 0313, 0164, 0217, 0163, 0052, 0111, 0354, 0227, 
  0322, 0276, 0045, 0204, 0235, 0351, 0015, 0327, 0164, 0234, 0010, 0260, 0102, 0260, 0304, 0137, 
  0254, 0275, 0036, 0075, 0061, 0177, 0121, 0226, 0000, 0205, 0040, 0017, 0335, 0332, 0025, 0143, 
  0355, 0325, 0301, 0102, 0076, 0163, 0255, 0366, 0247, 0166, 0147, 0147, 0251, 0367, 0340, 0027, 
  0224, 0305, 0036, 0157, 0015, 0350, 0150, 0273, 0360, 0366, 0155, 0004, 0301, 0312, 0127, 0173, 
  0253, 0140, 0353, 0113, 0076, 0036, 0123, 0150, 0357, 0056, 0373, 0102, 0075, 0312, 0301, 0134, 
  0355, 0157, 0224, 0130, 0226, 0067, 0266, 0025, 0223, 0037, 0330, 0145, 0366, 0375, 0145, 0364, 
  0333, 0061, 0173, 0374, 0120, 0353, 0266, 0335, 0175, 0335, 0366, 0056, 0353, 0266, 0013, 0036, 
  0221, 0354, 0053, 0267, 0133, 0123, 0271, 0175, 0044, 0237, 0000, 0127, 0255, 0267, 0372, 0143, 
  0336, 0325, 0065, 0256, 0064, 0366, 0362, 0337, 0045, 0350, 0344, 0257, 0325, 0213, 0055, 0265, 
  0372, 0030, 0011, 0110, 0142, 0316, 0022, 0065, 0233, 0103, 0257, 0137, 0370, 0065, 0000, 0265, 
  0033, 0213, 0375, 0156, 0364, 0257, 0353, 0134, 0316, 0240, 0167, 0120, 0370, 0125, 0231, 0377, 
  0001, 0322, 0065, 0047, 0276, 0000, 0050, 0165, 0165, 0141, 0171, 0051, 0141, 0160, 0160, 0154, 
  0145, 0164, 0057, 0000, 0005, 0000, 0000, 0000, 0147, 0156, 0157, 0155, 0145, 0057, 0000, 0000, 
  0001, 0000, 0000, 0000
} };
#else /* _MSC_VER */
static const SECTION union { const guint8 data[3701]; const double alignment; void * const ptr;}  wncklet_resource_data = {
  "\107\126\141\162\151\141\156\164\000\000\000\000\000\000\000\000"
  "\030\000\000\000\070\001\000\000\000\000\000\050\012\000\000\000"
  "\000\000\000\000\001\000\000\000\002\000\000\000\005\000\000\000"
  "\006\000\000\000\006\000\000\000\007\000\000\000\011\000\000\000"
  "\011\000\000\000\012\000\000\000\324\265\002\000\377\377\377\377"
  "\070\001\000\000\001\000\114\000\074\001\000\000\100\001\000\000"
  "\157\330\366\224\011\000\000\000\100\001\000\000\006\000\114\000"
  "\110\001\000\000\114\001\000\000\276\100\116\365\005\000\000\000"
  "\114\001\000\000\032\000\166\000\150\001\000\000\015\002\000\000"
  "\230\045\111\067\005\000\000\000\015\002\000\000\016\000\166\000"
  "\040\002\000\000\362\006\000\000\032\212\367\210\005\000\000\000"
  "\362\006\000\000\023\000\166\000\010\007\000\000\250\007\000\000"
  "\253\234\262\161\010\000\000\000\250\007\000\000\010\000\114\000"
  "\260\007\000\000\300\007\000\000\113\120\220\013\000\000\000\000"
  "\300\007\000\000\004\000\114\000\304\007\000\000\310\007\000\000"
  "\274\045\206\141\005\000\000\000\310\007\000\000\025\000\166\000"
  "\340\007\000\000\134\016\000\000\104\237\231\330\001\000\000\000"
  "\134\016\000\000\007\000\114\000\144\016\000\000\150\016\000\000"
  "\260\267\044\060\006\000\000\000\150\016\000\000\006\000\114\000"
  "\160\016\000\000\164\016\000\000\057\000\000\000\006\000\000\000"
  "\160\141\156\145\154\057\000\000\010\000\000\000\167\157\162\153"
  "\163\160\141\143\145\055\163\167\151\164\143\150\145\162\055\155"
  "\145\156\165\056\165\151\000\000\031\001\000\000\001\000\000\000"
  "\170\332\175\120\101\016\302\060\014\273\357\025\125\357\243\037"
  "\350\372\006\176\200\322\342\211\212\266\233\322\114\023\277\247"
  "\003\301\220\220\166\264\343\070\166\154\054\002\036\051\300\165"
  "\112\331\214\262\250\170\035\364\072\361\275\316\215\356\353\032"
  "\045\334\300\375\066\323\233\252\351\052\202\304\251\274\121\303"
  "\121\220\077\240\101\022\341\350\027\201\052\224\061\350\104\036"
  "\111\053\141\052\065\221\220\117\215\174\240\152\167\071\063\106"
  "\060\112\100\265\346\273\167\340\105\257\313\332\375\047\074\315"
  "\207\136\326\354\051\255\371\151\140\315\126\315\165\115\260\077"
  "\343\011\160\207\133\067\000\050\165\165\141\171\051\167\151\156"
  "\144\157\167\055\154\151\163\164\056\165\151\000\000\000\000\000"
  "\244\076\000\000\001\000\000\000\170\332\355\133\335\163\342\066"
  "\020\177\277\277\102\325\153\207\020\223\266\227\316\200\157\222"
  "\273\134\172\163\371\232\204\233\173\324\010\173\001\065\102\242"
  "\222\214\223\116\377\370\312\066\011\044\010\214\015\327\320\104"
  "\157\301\332\135\153\177\253\375\214\325\376\160\067\342\150\002"
  "\112\063\051\072\070\330\333\307\010\104\044\143\046\006\035\374"
  "\255\373\271\161\210\077\204\357\332\077\065\032\350\024\004\050"
  "\152\040\106\051\063\103\064\340\064\006\164\260\027\034\356\035"
  "\240\106\303\022\061\141\100\365\151\004\341\073\204\332\012\376"
  "\112\230\002\215\070\353\165\360\300\334\376\214\147\057\262\154"
  "\055\334\314\351\144\357\117\210\014\212\070\325\272\203\117\315"
  "\355\047\106\271\034\140\304\342\016\066\124\337\162\246\015\031"
  "\053\071\006\145\030\150\022\027\353\031\263\145\237\056\334\043"
  "\101\107\320\301\021\025\244\057\243\104\343\360\063\345\032\332"
  "\315\007\002\067\175\117\252\030\024\111\131\154\206\070\374\265"
  "\214\334\060\303\001\043\243\250\320\234\032\332\343\366\341\075"
  "\330\267\175\147\042\226\051\072\263\233\105\127\012\372\240\054"
  "\216\240\113\005\336\217\201\014\055\162\070\024\122\215\050\137"
  "\140\210\206\214\307\050\307\126\120\336\310\177\166\360\244\047"
  "\357\246\020\270\060\074\266\253\071\200\005\130\215\214\274\365"
  "\110\277\270\215\011\323\314\352\202\303\256\112\026\060\253\203"
  "\263\213\107\052\006\302\120\143\117\000\016\047\231\065\243\105"
  "\175\135\214\172\114\043\173\040\161\330\162\122\347\220\314\176"
  "\257\304\043\003\042\300\363\304\065\300\250\013\310\106\240\270"
  "\230\141\142\171\355\033\117\077\175\045\127\227\137\056\272\047"
  "\327\344\374\262\373\345\362\202\234\037\335\174\105\377\040\307"
  "\312\037\366\327\374\362\361\267\156\327\076\276\272\076\271\271"
  "\161\074\277\076\071\073\071\272\071\311\127\326\335\127\211\127"
  "\225\332\071\070\134\312\262\140\354\065\014\376\036\077\147\250"
  "\151\364\115\014\277\261\361\127\042\366\333\112\056\047\150\156"
  "\340\316\150\017\170\001\035\317\376\014\260\213\157\003\374\066"
  "\305\320\305\177\107\071\033\130\010\367\253\062\362\102\333\222"
  "\170\376\121\332\350\053\114\251\160\152\214\142\275\304\200\166"
  "\023\314\223\114\067\220\002\033\014\215\315\214\224\047\271\343"
  "\360\270\310\213\016\336\346\152\371\355\146\141\114\347\232\075"
  "\047\267\366\240\254\207\012\334\215\251\210\153\332\242\317\070"
  "\257\311\072\226\232\025\276\120\142\110\273\272\114\237\166\163"
  "\311\141\257\342\004\117\242\307\357\377\007\017\030\121\065\140"
  "\202\150\103\225\055\045\202\126\125\376\312\221\250\176\064\132"
  "\155\014\267\101\256\151\314\344\161\142\214\335\136\156\030\075"
  "\224\051\211\022\145\253\054\103\124\266\212\227\111\253\342\365"
  "\067\103\142\235\076\315\175\137\243\276\222\043\064\175\011\112"
  "\245\272\315\024\054\065\315\306\147\243\344\174\324\025\241\040"
  "\002\066\311\012\150\350\323\204\233\065\117\232\113\124\242\201"
  "\044\302\246\170\316\304\006\112\255\035\266\135\314\064\062\126"
  "\233\372\057\217\025\115\211\065\264\075\350\106\252\165\345\254"
  "\012\262\345\201\166\343\140\273\141\300\335\050\350\226\004\336"
  "\225\301\167\173\076\117\071\337\252\277\077\167\167\112\070\237"
  "\371\272\366\316\276\023\316\136\317\131\027\345\014\224\114\306"
  "\070\134\314\036\157\333\363\203\037\351\371\073\125\227\326\251"
  "\315\326\306\251\172\131\272\014\233\345\270\324\306\244\036\036"
  "\265\262\305\022\034\234\030\324\152\350\203\300\167\364\265\073"
  "\372\203\267\335\321\237\146\051\300\042\354\273\371\067\331\315"
  "\007\055\337\316\357\136\073\057\300\156\222\344\325\331\026\253"
  "\173\162\221\211\105\271\330\207\052\337\027\364\276\173\367\335"
  "\373\013\164\357\064\061\162\353\036\176\072\357\332\050\035\202"
  "\100\044\157\334\021\313\376\361\074\142\006\142\357\361\257\261"
  "\205\137\310\030\276\203\337\151\357\347\051\275\327\333\317\360"
  "\107\271\134\237\342\275\303\277\061\207\157\371\221\235\037\331"
  "\125\034\331\005\057\071\262\073\360\043\273\072\043\273\021\023"
  "\266\214\375\033\142\062\315\156\244\310\206\157\163\206\167\015"
  "\332\346\022\013\066\072\177\300\005\175\137\057\353\373\171\336"
  "\353\234\347\375\342\347\171\273\067\317\033\311\011\220\131\350"
  "\332\136\301\137\004\000\100\106\076\176\230\103\374\227\071\176"
  "\266\347\147\173\057\331\335\107\103\052\006\060\163\304\037\343"
  "\360\202\222\354\140\371\057\361\136\167\243\357\312\035\176\270"
  "\347\173\175\337\353\127\351\365\133\333\350\365\135\372\273\165"
  "\257\245\167\165\235\053\333\336\241\353\202\236\113\256\330\145"
  "\145\214\024\204\052\240\270\344\166\131\236\012\237\337\271\233"
  "\343\157\275\350\215\263\165\307\065\163\011\075\226\002\110\257"
  "\170\120\176\352\126\314\347\077\162\131\355\334\157\143\004\124"
  "\207\365\061\025\127\145\036\122\135\237\271\106\045\260\121\005"
  "\360\342\001\255\062\333\226\247\227\273\037\321\354\136\110\166"
  "\053\030\207\040\342\377\060\016\076\105\346\311\142\273\010\145"
  "\215\224\305\003\060\217\343\255\247\217\221\002\075\226\102\333"
  "\335\354\343\160\056\200\264\233\117\350\036\344\057\312\234\355"
  "\240\335\234\273\113\376\057\312\142\114\041\000\050\165\165\141"
  "\171\051\167\151\156\144\157\167\055\154\151\163\164\055\155\145"
  "\156\165\056\165\151\000\000\000\013\001\000\000\001\000\000\000"
  "\170\332\175\217\101\016\203\060\014\004\357\274\042\312\235\346"
  "\003\041\157\350\017\052\003\213\144\051\061\125\142\204\372\373"
  "\046\255\132\070\161\234\365\172\275\366\054\212\274\320\204\320"
  "\031\343\023\144\063\074\017\166\147\231\327\275\217\134\264\157"
  "\242\155\343\152\050\230\224\127\371\122\145\126\244\037\124\044"
  "\325\314\343\246\060\102\011\203\215\064\042\132\243\231\244\104"
  "\122\032\143\025\137\050\066\074\356\031\013\062\144\102\361\356"
  "\277\167\221\105\237\313\066\234\252\335\236\227\041\336\035\365"
  "\274\073\125\367\256\375\024\272\152\070\336\177\003\277\367\125"
  "\157\000\050\165\165\141\171\051\167\156\143\153\154\145\164\057"
  "\004\000\000\000\003\000\000\000\002\000\000\000\007\000\000\000"
  "\157\162\147\057\011\000\000\000\167\157\162\153\163\160\141\143"
  "\145\055\163\167\151\164\143\150\145\162\056\165\151\000\000\000"
  "\256\106\000\000\001\000\000\000\170\332\355\134\337\163\333\050"
  "\020\176\357\137\301\351\365\306\115\234\134\073\275\216\343\116"
  "\177\244\275\116\333\264\023\247\327\107\015\226\326\026\015\006"
  "\035\102\166\162\163\177\374\201\344\330\162\214\054\044\224\306"
  "\116\374\226\010\166\201\135\366\343\323\056\162\357\325\325\204"
  "\242\051\210\204\160\166\342\165\237\036\172\010\130\300\103\302"
  "\306\047\336\367\213\367\235\027\336\253\376\223\336\157\235\016"
  "\372\000\014\004\226\020\242\031\221\021\032\123\034\002\072\176"
  "\332\175\361\364\030\165\072\252\023\141\022\304\010\007\320\177"
  "\202\120\117\300\077\051\021\220\040\112\206\047\336\130\136\376"
  "\356\055\007\122\142\107\336\101\326\217\017\177\102\040\121\100"
  "\161\222\234\170\037\344\345\353\360\147\232\310\011\060\351\041"
  "\022\236\170\054\235\370\202\317\022\037\057\033\264\244\222\215"
  "\005\217\101\310\153\304\360\004\116\074\312\147\040\274\176\267"
  "\167\160\323\140\356\227\306\161\326\357\171\125\307\051\246\051"
  "\130\050\114\044\304\076\141\201\200\174\166\225\002\061\036\303"
  "\212\300\341\252\104\357\040\067\213\275\205\146\134\134\046\261"
  "\062\176\373\166\072\336\125\073\275\043\230\362\161\156\043\255"
  "\111\370\163\131\242\254\024\346\215\346\161\003\314\374\021\017"
  "\322\304\353\277\307\064\201\252\171\016\271\010\225\372\031\011"
  "\145\344\365\237\125\165\227\104\122\360\220\024\230\045\024\113"
  "\074\244\352\341\065\250\321\176\334\270\021\015\124\224\005\021"
  "\010\364\115\300\010\204\212\112\110\252\364\252\160\043\377\152"
  "\155\226\323\226\327\061\370\021\321\226\145\134\114\060\135\023"
  "\010\042\102\103\224\105\066\303\264\223\375\253\374\075\344\127"
  "\163\313\231\354\376\106\265\146\106\317\155\334\321\335\273\213"
  "\376\206\355\103\022\222\115\372\102\244\153\163\156\342\036\223"
  "\014\027\104\155\041\054\025\376\170\375\251\336\004\301\372\172"
  "\215\233\126\271\103\301\241\327\077\062\366\066\133\010\007\172"
  "\040\037\013\300\205\205\033\215\225\112\311\331\155\223\025\344"
  "\273\053\012\032\130\257\251\005\227\313\133\175\126\276\212\371"
  "\022\070\003\177\230\077\270\055\151\000\043\074\004\152\214\005"
  "\377\055\345\345\063\153\154\212\012\163\064\021\015\141\204\123"
  "\052\353\013\107\070\151\056\054\040\000\062\205\202\206\215\256"
  "\064\042\174\002\176\312\024\164\121\302\052\315\126\004\333\125"
  "\245\070\270\124\021\122\075\034\134\305\230\205\015\346\071\042"
  "\224\066\020\213\171\102\362\200\357\156\132\226\161\376\275\203"
  "\265\255\157\062\200\171\361\215\026\156\136\164\235\250\326\163"
  "\361\065\250\173\175\140\241\265\324\302\112\207\146\021\203\205"
  "\326\254\263\016\024\033\316\005\175\040\034\335\053\254\325\073"
  "\277\235\317\224\215\347\112\367\310\025\175\337\013\245\061\067"
  "\355\110\377\331\365\176\015\126\326\016\110\230\052\173\051\301"
  "\017\357\076\371\337\276\176\074\273\070\075\367\277\174\275\370"
  "\370\365\314\377\362\172\360\011\375\207\014\055\177\251\377\212"
  "\315\157\276\137\134\250\307\337\316\117\007\003\303\363\363\323"
  "\317\247\257\007\247\131\113\235\271\145\007\221\177\205\051\031"
  "\227\207\102\211\053\043\034\362\331\074\362\230\072\376\066\012"
  "\033\235\152\021\061\317\074\223\220\203\147\135\275\153\222\237"
  "\140\061\046\314\117\044\026\162\323\326\156\045\244\052\103\353"
  "\171\245\144\251\063\314\016\071\307\041\341\105\262\023\244\102"
  "\161\163\351\163\106\257\175\241\133\275\062\155\165\270\317\040"
  "\342\063\224\051\105\062\002\064\037\005\055\336\362\252\326\345"
  "\274\057\034\131\122\213\234\245\025\356\122\256\306\052\340\313"
  "\204\065\115\237\072\014\036\012\074\123\357\267\241\332\344\222"
  "\013\133\075\145\104\254\232\220\071\023\063\107\202\326\230\202"
  "\130\020\266\015\304\255\171\274\057\000\070\122\000\374\247\167"
  "\077\301\326\330\254\026\024\303\336\070\226\200\210\051\055\046"
  "\243\252\040\261\011\054\252\041\226\110\230\250\167\357\227\066"
  "\253\153\305\113\055\301\142\313\320\330\042\074\072\103\144\173"
  "\060\147\326\065\026\074\215\275\376\372\271\153\247\260\012\073"
  "\355\360\263\025\014\155\001\107\235\261\324\002\117\053\061\265"
  "\051\164\254\140\153\367\320\273\337\320\165\262\271\075\341\264"
  "\067\230\331\150\203\230\260\042\334\056\252\043\211\152\360\252"
  "\364\265\144\306\026\121\320\230\226\206\053\151\204\377\256\213"
  "\326\142\131\304\120\123\162\132\073\045\223\241\257\213\143\216"
  "\163\124\363\002\101\002\167\023\226\125\144\334\200\321\036\034"
  "\133\003\310\146\211\261\073\301\111\113\254\264\302\113\027\010"
  "\370\234\323\043\035\375\171\316\102\355\144\077\340\164\113\242"
  "\337\331\275\265\351\106\075\016\251\343\336\105\263\006\014\062"
  "\272\126\024\004\164\321\307\105\325\204\301\204\063\022\350\304"
  "\343\030\212\270\244\321\374\001\307\256\263\032\253\314\376\335"
  "\005\357\116\260\110\027\142\124\333\276\356\044\162\153\263\032"
  "\115\337\340\153\331\260\171\122\243\334\156\245\102\363\242\265"
  "\316\127\337\040\245\135\076\372\366\321\163\264\013\051\351\155"
  "\052\072\324\114\167\314\357\200\124\152\304\122\012\062\114\045"
  "\044\245\373\153\321\145\076\352\014\310\070\122\064\073\143\212"
  "\272\002\106\303\374\106\226\151\207\155\326\137\173\007\336\173"
  "\045\271\156\315\313\212\053\332\027\222\033\125\366\012\111\265"
  "\254\310\267\257\361\075\300\032\137\167\137\343\273\367\032\337"
  "\112\136\352\217\175\316\177\023\013\270\165\365\264\234\113\354"
  "\110\042\317\071\325\135\176\230\237\245\223\041\010\304\107\250"
  "\140\261\227\133\220\336\157\370\102\153\365\062\133\330\033\366"
  "\257\264\373\034\375\326\344\350\115\351\346\133\076\365\166\267"
  "\344\346\236\150\256\112\062\033\257\345\067\136\165\223\064\163"
  "\053\051\146\267\364\362\076\133\362\210\262\045\017\357\016\110"
  "\201\356\054\302\331\327\163\256\346\073\133\311\020\235\156\074"
  "\225\363\233\345\247\053\014\373\023\113\152\163\107\227\272\326"
  "\270\110\001\207\245\000\360\247\004\146\217\373\242\125\167\273"
  "\202\154\020\010\116\051\204\077\010\123\257\331\346\150\113\262"
  "\076\065\302\055\312\162\134\276\376\024\021\222\354\363\261\303"
  "\135\275\070\271\222\176\260\043\322\115\370\336\205\012\216\277"
  "\125\154\254\245\234\026\121\263\313\164\217\163\052\111\354\227"
  "\322\276\045\204\235\351\015\327\164\234\010\260\102\260\304\137"
  "\254\275\036\075\061\177\121\226\000\205\040\017\335\332\025\143"
  "\355\325\301\102\076\163\255\366\247\166\147\147\251\367\340\027"
  "\224\305\036\157\015\350\150\273\360\366\155\004\301\312\127\173"
  "\253\140\353\113\076\036\123\150\357\056\373\102\075\312\301\134"
  "\355\157\224\130\226\067\266\025\223\037\330\145\366\375\145\364"
  "\333\061\173\374\120\353\266\335\175\335\366\056\353\266\013\036"
  "\221\354\053\267\133\123\271\175\044\237\000\127\255\267\372\143"
  "\336\325\065\256\064\366\362\337\045\350\344\257\325\213\055\265"
  "\372\030\011\110\142\316\022\065\233\103\257\137\370\065\000\265"
  "\033\213\375\156\364\257\353\134\316\240\167\120\370\125\231\377"
  "\001\322\065\047\276\000\050\165\165\141\171\051\141\160\160\154"
  "\145\164\057\000\005\000\000\000\147\156\157\155\145\057\000\000"
  "\001\000\000\000" };
#endif /* !_MSC_VER */

static GStaticResource static_resource = { wncklet_resource_data.data, sizeof (wncklet_resource_data.data) - 1 /* nul terminator */, NULL, NULL, NULL };

G_MODULE_EXPORT
GResource *wncklet_get_resource (void);
GResource *wncklet_get_resource (void)
{
  return g_static_resource_get_resource (&static_resource);
}
/*
  If G_HAS_CONSTRUCTORS is true then the compiler support *both* constructors and
  destructors, in a usable way, including e.g. on library unload. If not you're on
  your own.

  Some compilers need #pragma to handle this, which does not work with macros,
  so the way you need to use this is (for constructors):

  #ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
  #pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(my_constructor)
  #endif
  G_DEFINE_CONSTRUCTOR(my_constructor)
  static void my_constructor(void) {
   ...
  }

*/

#ifndef __GTK_DOC_IGNORE__

#if  __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 7)

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR(_func) static void __attribute__((constructor)) _func (void);
#define G_DEFINE_DESTRUCTOR(_func) static void __attribute__((destructor)) _func (void);

#elif defined (_MSC_VER) && (_MSC_VER >= 1500)
/* Visual studio 2008 and later has _Pragma */

#include <stdlib.h>

#define G_HAS_CONSTRUCTORS 1

/* We do some weird things to avoid the constructors being optimized
 * away on VS2015 if WholeProgramOptimization is enabled. First we
 * make a reference to the array from the wrapper to make sure its
 * references. Then we use a pragma to make sure the wrapper function
 * symbol is always included at the link stage. Also, the symbols
 * need to be extern (but not dllexport), even though they are not
 * really used from another object file.
 */

/* We need to account for differences between the mangling of symbols
 * for Win32 (x86) and x64 programs, as symbols on Win32 are prefixed
 * with an underscore but symbols on x64 are not.
 */
#ifdef _WIN64
#define G_MSVC_SYMBOL_PREFIX ""
#else
#define G_MSVC_SYMBOL_PREFIX "_"
#endif

#define G_DEFINE_CONSTRUCTOR(_func) G_MSVC_CTOR (_func, G_MSVC_SYMBOL_PREFIX)
#define G_DEFINE_DESTRUCTOR(_func) G_MSVC_DTOR (_func, G_MSVC_SYMBOL_PREFIX)

#define G_MSVC_CTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _wrapper(void) { _func(); g_slist_find (NULL,  _array ## _func); return 0; } \
  __pragma(comment(linker,"/include:" _sym_prefix # _func "_wrapper")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _wrapper;

#define G_MSVC_DTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _constructor(void) { atexit (_func); g_slist_find (NULL,  _array ## _func); return 0; } \
   __pragma(comment(linker,"/include:" _sym_prefix # _func "_constructor")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _constructor;

#elif defined (_MSC_VER)

#define G_HAS_CONSTRUCTORS 1

/* Pre Visual studio 2008 must use #pragma section */
#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _wrapper(void) { _func(); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (*p)(void) = _func ## _wrapper;

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _constructor(void) { atexit (_func); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (* _array ## _func)(void) = _func ## _constructor;

#elif defined(__SUNPRO_C)

/* This is not tested, but i believe it should work, based on:
 * http://opensource.apple.com/source/OpenSSL098/OpenSSL098-35/src/fips/fips_premain.c
 */

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  init(_func)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void);

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  fini(_func)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void);

#else

/* constructors not supported for this compiler */

#endif

#endif /* __GTK_DOC_IGNORE__ */

#ifdef G_HAS_CONSTRUCTORS

#ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(resource_constructor)
#endif
G_DEFINE_CONSTRUCTOR(resource_constructor)
#ifdef G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(resource_destructor)
#endif
G_DEFINE_DESTRUCTOR(resource_destructor)

#else
#warning "Constructor not supported on this compiler, linking in resources will not work"
#endif

static void resource_constructor (void)
{
  g_static_resource_init (&static_resource);
}

static void resource_destructor (void)
{
  g_static_resource_fini (&static_resource);
}
